@@ -1,6 +1,7 @@
 """Solvers.
 
-This submodule contains the solvers for the computation of thermal processes.
+This submodule contains the solvers for the computation of the unidimensional
+thermal processes.
 
 """
 
@@ -9,4 +10,4 @@ from .implicit_general import implicit_general
 from .explicit_k import explicit_k
 from .explicit_general import explicit_general
 
-__all__ = [implicit_k, implicit_general, explicit_k, explicit_general]
+__all__ = ['implicit_k', 'implicit_general', 'explicit_k', 'explicit_general']
