@@ -6,4 +6,4 @@ This submodule access the properties of materials
 
 from .calmatpro import CalMatPro
 
-__all__ = [CalMatPro]
+__all__ = ['CalMatPro']
